@@ -8,7 +8,7 @@ use crate::payment::cancel as cancel_payment;
 use crate::payment::process as process_payment;
 use crate::payment::PaymentProcessor;
 use crate::payment::{Initiator, Payment};
-use crate::shipping::FulfillmentTypeSelection;
+use crate::shipping::FulfillmentSelection;
 
 pub async fn get_handler<C: Context + Send>(
     ctx: &mut C,
@@ -141,10 +141,10 @@ pub async fn update_shipping_address_handler<C: Context + Send>(
     Ok(co)
 }
 
-pub async fn update_fulfillment_type_handler<C: Context + Send>(
+pub async fn update_fulfillment_handler<C: Context + Send>(
     ctx: &mut C,
     checkout_id: &str,
-    fulfillment_type: FulfillmentTypeSelection,
+    fulfillment: FulfillmentSelection,
 ) -> Result<Checkout<Payment<<C as PaymentProcessor>::Data>>, Error> {
     let maybe_co = ctx.get_checkout_for_update(&checkout_id).await?;
     if maybe_co.is_none() {
@@ -155,7 +155,7 @@ pub async fn update_fulfillment_type_handler<C: Context + Send>(
 
     let mut co = maybe_co.unwrap();
 
-    co.update_fulfillment_type(ctx, fulfillment_type).await?;
+    co.update_fulfillment(ctx, fulfillment).await?;
     co.populate_associations(ctx).await?;
 
     Ok(co)
