@@ -16,7 +16,7 @@ use crate::money::{Currency, Money};
 use crate::order::Order;
 use crate::payment::handlers as payment_handlers;
 use crate::payment::{Initiator, PaymentProcessor};
-use crate::shipping::{FulfillmentType, FulfillmentTypeSelection, ShippingQuote};
+use crate::shipping::{Fulfillment, FulfillmentSelection, ShippingQuote};
 
 pub mod handlers;
 
@@ -37,7 +37,7 @@ pub struct Checkout<P> {
     pub items: Vec<Item>,
     pub contact: Option<Contact>,
     pub shipping_address: Option<Address>,
-    pub fulfillment_type: Option<FulfillmentType>,
+    pub fulfillment: Option<Fulfillment>,
     pub shipping_quotes: Vec<ShippingQuote>,
     pub invoice: Option<Invoice>,
     pub payment_id: Option<String>,
@@ -83,7 +83,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
             items: vec![],
             contact,
             shipping_address,
-            fulfillment_type: None,
+            fulfillment: None,
             shipping_quotes: vec![],
             invoice: None,
             payment_id: None,
@@ -199,7 +199,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
                 }
 
                 // check for a fulfillment type
-                if self.fulfillment_type.is_none() {
+                if self.fulfillment.is_none() {
                     return Err(new_application_error(
                         "MISSING_FULFILLMENT_TYPE",
                         "please select a fulfillment type to continue",
@@ -228,7 +228,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
                 }
 
                 // check for a fulfillment type
-                if self.fulfillment_type.is_none() {
+                if self.fulfillment.is_none() {
                     return Err(new_application_error(
                         "MISSING_FULFILLMENT_TYPE",
                         "please select a fulfillment type to continue",
@@ -276,7 +276,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
     }
 
     fn reset_shipping_options(&mut self) {
-        self.fulfillment_type = None;
+        self.fulfillment = None;
         self.shipping_quotes = vec![];
     }
 }
@@ -394,23 +394,25 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
         ctx.update_checkout(self).await
     }
 
-    pub async fn update_fulfillment_type<C: Context + Send>(
+    pub async fn update_fulfillment<C: Context + Send>(
         &mut self,
         ctx: &mut C,
-        fulfillment_type: FulfillmentTypeSelection,
+        fulfillment: FulfillmentSelection,
     ) -> Result<(), Error> {
         self.ensure_items_confirmed_state(ctx).await?;
 
-        match fulfillment_type {
-            FulfillmentTypeSelection::Pickup => {
-                self.fulfillment_type = Some(FulfillmentType::Pickup);
+        match fulfillment {
+            FulfillmentSelection::Pickup => {
+                self.fulfillment = Some(Fulfillment::Pickup);
             }
-            FulfillmentTypeSelection::Shipping(quote_id) => {
+            FulfillmentSelection::Shipping { quote_id } => {
                 let mut updated = false;
 
                 for quote in self.shipping_quotes.iter() {
                     if quote.id == quote_id {
-                        self.fulfillment_type = Some(FulfillmentType::Shipping(quote.clone()));
+                        self.fulfillment = Some(Fulfillment::Shipping {
+                            quote: quote.clone(),
+                        });
                         updated = true;
                         break;
                     }
