@@ -6,8 +6,8 @@ use crate::error::{new_server_error, Error};
 #[derive(Clone)]
 pub struct InternalContext {
     pub pubsub_client: Arc<Client>,
-    pub payment_processing_topic: Arc<Topic>,
-    pub payment_processing_subscription: Arc<Subscription>,
+    pub payment_callbacks_topic: Arc<Topic>,
+    pub payment_callbacks_subscription: Arc<Subscription>,
     pub order_events_topic: Arc<Topic>,
     pub order_events_subscription: Arc<Subscription>,
 }
@@ -15,7 +15,7 @@ pub struct InternalContext {
 impl InternalContext {
     pub async fn new(
         google_application_credentials: String,
-        payment_processing_topic_name: String,
+        payment_callbacks_topic_name: String,
         order_events_topic_name: String,
     ) -> Result<Self, Error> {
         let pubsub_client = Arc::new(
@@ -24,11 +24,11 @@ impl InternalContext {
                 .map_err(|_| new_server_error("failed to create pubsub client"))?,
         );
 
-        let payment_processing_topic =
-            Arc::new(pubsub_client.topic(payment_processing_topic_name.clone()));
+        let payment_callbacks_topic =
+            Arc::new(pubsub_client.topic(payment_callbacks_topic_name.clone()));
 
-        let payment_processing_subscription =
-            Arc::new(pubsub_client.subscribe(payment_processing_topic_name));
+        let payment_callbacks_subscription =
+            Arc::new(pubsub_client.subscribe(payment_callbacks_topic_name));
 
         let order_events_topic = Arc::new(pubsub_client.topic(order_events_topic_name.clone()));
 
@@ -36,8 +36,8 @@ impl InternalContext {
 
         Ok(Self {
             pubsub_client,
-            payment_processing_topic,
-            payment_processing_subscription,
+            payment_callbacks_topic,
+            payment_callbacks_subscription,
             order_events_topic,
             order_events_subscription,
         })
