@@ -380,12 +380,13 @@ impl<'a, C: ClientContext + Send> PaymentStore for MasterContext<'a, C> {
 #[async_trait]
 impl<'a, C: ClientContext + Send> PaymentProcessor for MasterContext<'a, C> {
     type Data = <C as PaymentProcessor>::Data;
+    type InitArgs = <C as PaymentProcessor>::InitArgs;
     type ProcessArgs = <C as PaymentProcessor>::ProcessArgs;
 
     async fn initiate_payment(
         &mut self,
         payment: &Payment<Self::Data>,
-        args: &Self::ProcessArgs,
+        args: &Self::InitArgs,
     ) -> Result<PaymentData<Self::Data>, Error> {
         self.client_ctx.initiate_payment(payment, args).await
     }
