@@ -15,7 +15,7 @@ use crate::{
     item::Item,
     payment::{handlers as payment_handlers, Initiator},
     payment::{Payment, PaymentProcessor},
-    shipping::FulfillmentType,
+    shipping::Fulfillment,
 };
 
 pub mod handlers;
@@ -28,7 +28,7 @@ pub struct Order<P> {
     pub contact: Contact,
     pub shipping_address: Address,
     pub items: Vec<Item>,
-    pub fulfillment_type: FulfillmentType,
+    pub fulfillment: Fulfillment,
     pub invoice: Invoice,
     pub payment_id: Option<String>,
     // associations
@@ -133,7 +133,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Order<P> {
             contact: checkout.contact.as_ref().unwrap().clone(),
             shipping_address: checkout.shipping_address.as_ref().unwrap().clone(),
             items: checkout.items.clone(),
-            fulfillment_type: checkout.fulfillment_type.as_ref().unwrap().clone(),
+            fulfillment: checkout.fulfillment.as_ref().unwrap().clone(),
             invoice: checkout.invoice.as_ref().unwrap().clone(),
             payment_id: checkout.payment_id.clone(),
             // associations
@@ -161,7 +161,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Order<P> {
             contact: checkout.contact.as_ref().unwrap().clone(),
             shipping_address: checkout.shipping_address.as_ref().unwrap().clone(),
             items: checkout.items.clone(),
-            fulfillment_type: checkout.fulfillment_type.as_ref().unwrap().clone(),
+            fulfillment: checkout.fulfillment.as_ref().unwrap().clone(),
             invoice: checkout.invoice.as_ref().unwrap().clone(),
             payment_id: None,
             // associations
