@@ -8,15 +8,17 @@ use crate::item::Item;
 use crate::money::{Currency, Money};
 
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
-pub enum FulfillmentType {
+#[serde(tag = "type", rename_all = "snake_case")]
+pub enum Fulfillment {
     Pickup,
-    Shipping(ShippingQuote),
+    Shipping { quote: ShippingQuote },
 }
 
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
-pub enum FulfillmentTypeSelection {
+#[serde(tag = "type", rename_all = "snake_case")]
+pub enum FulfillmentSelection {
     Pickup,
-    Shipping(String),
+    Shipping { quote_id: String },
 }
 
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
